@@ -5,9 +5,9 @@ Basic context-free grammars manipulation for building uniform random generetors
 
 .. *Authors:* Rogério Reis & Nelma Moreira
 
-.. *This is part of FAdo project* http://fado.dcc.fc.up.pt
+.. *This is part of FAdo project* https://fado.dcc.fc.up.pt
 
-.. *Copyright:* 1999-2014 Rogério Reis & Nelma Moreira {rvr,nam}@dcc.fc.up.pt
+.. *Copyright:* 1999-2022 Rogério Reis & Nelma Moreira {rvr,nam}@dcc.fc.up.pt
 
 
 .. This program is free software; you can redistribute it and/or
@@ -24,14 +24,10 @@ Basic context-free grammars manipulation for building uniform random generetors
    with this program; if not, write to the Free Software Foundation, Inc.,
    675 Mass Ave, Cambridge, MA 02139, USA."""
 
-#__package__ = "FAdo"
+# __package__ = "FAdo"
 
 import re
-#import string
 from random import randint
-
-#import common
-
 from . import common
 
 # This is a workarround for python3
@@ -42,11 +38,11 @@ StringType = type("a")
 class CFGrammar(object):
     """ Class for context-free grammars
 
-     :var Rules: grammar rules
-     :var Terminals: terminals symbols
-     :var Nonterminals: nonterminals symbols
-     :var str Start: start symbol
-     :var ntr: dictionary of rules for each nonterminal"""
+     :ivar Rules: grammar rules
+     :ivar Terminals: terminals symbols
+     :ivar Nonterminals: nonterminals symbols
+     :ivar str Start: start symbol
+     :ivar ntr: dictionary of rules for each nonterminal"""
 
     def __init__(self, gram):
         """Initialization
@@ -85,7 +81,7 @@ class CFGrammar(object):
             lhs = self.Rules[n][0]
             rhs = self.Rules[n][1]
             if type(rhs) is not StringType and len(rhs) > 1:
-                rhs = str.join(rhs)
+                rhs = s.join(rhs)
             s += "{0:d} | {1:s} -> {2:s} \n".format(n, lhs, rhs)
         return "Grammar Rules:\n\n%s" % s
 
@@ -151,17 +147,18 @@ class CFGrammar(object):
 
 
 class CNF(CFGrammar):
-    """No useless nonterminals or epsilon rules are ALLOWED... Given a CFG grammar description generates one in CNF
-      Then its possible to random generate words of a given size. Before some pre-calculations are nedded."""
+    """ Chomsky Normal Form.
+    No useless nonterminals or eepsipsilon rules are ALLOWED... Given a CFG grammar description generates one in CNF
+    Then its possible to random generate words of a given size. Before some pre-calculations are needed."""
 
     def __init__(self, gram, mark="A@"):
-       # super(CNF, self).__init__(gram)
+        # super(CNF, self).__init__(gram)
         CFGrammar.__init__(self, gram)
         self.mark = mark
         self.newnt = 0
         self.nttr = {}
         self.unitary = self.get_unitary()
-        self.Chomsky()
+        self.chomsky()
 
     def get_unitary(self):
         return set([r for r in self.Rules if
@@ -207,7 +204,7 @@ class CNF(CFGrammar):
         self.Rules.append((lhs, (rhs[0], nta)))
         self.iter_rule(nta, rhs[1:], i)
 
-    def Chomsky(self):
+    def chomsky(self):
         """ Transform to CNF """
         self.elim_unitary()
         self.nttr = {}
@@ -238,8 +235,8 @@ class cfgGenerator(object):
             :type size: integer"""
         self.grammar = cfgr
         self.size = size
- #       self.density = {}
- #       self.density_r = {}
+#      self.density = {}
+#       self.density_r = {}
         self._eval_densities(size)
 
     def generate(self):
@@ -351,10 +348,10 @@ class reStringRGenerator(cfgGenerator):
             self.base.append((ident, common.Epsilon))
         if empty is not None:
             self.base.append((ident, common.EmptySet))
-        super(reStringRGenerator, self).__init__(CNF(self.base),size)
+        super(reStringRGenerator, self).__init__(CNF(self.base), size)
 
 
-#noinspection PyUnusedLocal
+# noinspection PyUnusedLocal
 def CYKParserTable(gramm, word):
     """Evaluates CYK parser table
 
@@ -375,7 +372,7 @@ def gRules(rules_list, rulesym="->", rhssep=None, rulesep='|'):
       :return: a grammar description """
     gr = []
     sep = re.compile(rulesym)
-    #rsep = re.compile(rulesep)
+    # rsep = re.compile(rulesep)
     for r in rules_list:
         if type(r) is StringType:
             rule = r
@@ -407,6 +404,7 @@ def gRules(rules_list, rulesym="->", rhssep=None, rulesep='|'):
                         gr.append((lhs, l))
     return gr
 
+
 def smallAlphabet(k, sigma_base="a"):
     """Easy way to have small alphabets
 
@@ -426,6 +424,7 @@ def smallAlphabet(k, sigma_base="a"):
             Sigma.append(chr(ord(sigma_base) + i))
     return Sigma
 
+
 reGrammar = {'g_regular_base': ["Tr -> Tr + Tc | Tc", "Tc -> Tc Ts |  Ts",
                                 "Ts -> Ts * | Ti | ( Tr ) "],
              'g_finite_base': ["Tr -> Tr + Tc | Tc", "Tc -> Tc Ts |  Ts",
@@ -435,7 +434,8 @@ reGrammar = {'g_regular_base': ["Tr -> Tr + Tc | Tc", "Tc -> Tc Ts |  Ts",
                                    "Tc -> Tc Ts |  Ts Ts",
                                    "Ts -> Te | Ti | ( Trs ) ",
                                    "Te -> ( Trs ) * | ( Tc ) * | Ti *"],
-             'g_regular_uncollaps': ["Ts ->  Trs | Tcc  | Tee | Ti | {0:s} | {1:s}".format(common.Epsilon, common.EmptySet),
+             'g_regular_uncollaps': ["Ts ->  Trs | Tcc  | Tee | Ti | {0:s} | {1:s}".format(common.Epsilon,
+                                                                                           common.EmptySet),
                                      "Tcc -> Tcc Tr | Tr Tr",
                                      "Tr -> ( Trs ) | Tee | Ti ",
                                      "Tee -> ( Trs ) * | ( Tcc ) * | Ti *",
@@ -460,21 +460,22 @@ reGrammar = {'g_regular_base': ["Tr -> Tr + Tc | Tc", "Tc -> Tc Ts |  Ts",
                        "Tz -> Tec | Tes | Ti"],
              'g_rpn': ["Tx -> {0:s} | Ti | +  Tx  Tx  | . Tx Tx  | * Tx".format(common.Epsilon)],
              'g_rpn_finite': ["Tx -> {0:s} | Ti | +  Tx  Tx  | . Tx Tx".format(common.Epsilon)],
-             'g_rpn_snf':["Tx ->  Tp | Tnp",
+             'g_rpn_snf': ["Tx ->  Tp | Tnp",
                     "Tp -> {0:s} | . Tp Tp | + Tp Tnp | + Tnp Tp | + Tp Tp |  * Tnp ".format(common.Epsilon),
                     "Tnp -> Ti | + Tnp Tnp | . Tp Tnp | . Tnp Tp | . Tnp Tnp"],
              'g_rpn_snf_uf': ["Tx ->  Tp | Tnp",
                            "Tp ->  . Tp Tp |   * Tnp ",
                            "Tnp -> Ti |  . Tp Tnp | . Tnp Tp | . Tnp Tnp"],
-             'g_rpn_option':["Tp -> {0:s} | Tx ".format(common.Epsilon),
+             'g_rpn_option': ["Tp -> {0:s} | Tx ".format(common.Epsilon),
                  "Tx ->  Ti | +  Tx  Tx  | . Tx Tx  | * Tx| {0:s} Tx".format(common.Option)],
-             'g_rpn_snf_option':["Tx -> {0:s} | Tp | Tnp".format(common.Epsilon),
+             'g_rpn_snf_option': ["Tx -> {0:s} | Tp | Tnp".format(common.Epsilon),
                     "Tp -> . Tp Tp | + Tp Tnp | + Tnp Tp | + Tp Tp |* Tnp| {0:s} Tnp".format(common.Option),
                     "Tnp -> Ti | + Tnp Tnp | . Tp Tnp | . Tnp Tp | . Tnp Tnp"],
-             'g_rpn_pi': [ "Tp -> Ti | +  Tp  Tx | + Tnp Tp | . Tx Tp | . Tp {0:s}".format(common.Epsilon),
+             'g_rpn_pi': ["Tp -> Ti | +  Tp  Tx | + Tnp Tp | . Tx Tp | . Tp {0:s}".format(common.Epsilon),
                            "Tx -> {0:s} | Ti | +  Tx  Tx  | . Tx Tx  | * Tx".format(common.Epsilon),
                            "Tnp -> {0:s} | +  Tnp  Tnp | . Tnp Tnp | . Tp Tnp".format(common.Epsilon)],
-             'grse_rpn': ["Tx -> {0:s} | Ti | +  Tx  Tx  | {1:s} Tx Tx | . Tx Tx  | * Tx".format(common.Epsilon, common.Shuffle)],
+             'grse_rpn': ["Tx -> {0:s} | Ti | +  Tx  Tx  | {1:s} Tx Tx | . Tx Tx  | * Tx".format(common.Epsilon,
+                                                                                                 common.Shuffle)],
              'grs_rpn': ["Tx ->  Ti | +  Tx  Tx  | {0:s} Tx Tx | . Tx Tx  | * Tx".format(common.Shuffle)],
              'grf_rpn': ["Tx ->  Ti | +  Tx  Tx  | {0:s} Tx Tx | . Tx Tx ".format(common.Shuffle)],
              'grce_rpn': ["Tx -> {0:s} | Ti | +  Tx  Tx  | {1:s} Tx Tx | . Tx Tx  | * Tx".format(common.Epsilon, common.Conj)],
@@ -482,17 +483,16 @@ reGrammar = {'g_regular_base': ["Tr -> Tr + Tc | Tc", "Tc -> Tc Ts |  Ts",
              'grcf_rpn': ["Tx ->  Ti | +  Tx  Tx  | {0:s} Tx Tx | . Tx Tx ".format(common.Conj)],
              'grcn_rpn': ["Tx ->  Ti | +  Tx  Tx  | {0:s} Tx Tx | . Tx Tx  | {1:s} Tx | * Tx".format(common.Conj, common.Not)],
              'grche_rpn': ["Ts -> {0:s} Tx Tx".format(common.Conj), "Tx ->  {0:s} |  Ti | +  Tx  Tx  | . Tx Tx  | * Tx".format(common.Epsilon)],
-             'grcv_rpn': [ "Tn -> Ti | + Tn Tx | + Tv Tn | * Tn | . Tn Tx | . Tv Tn | {0:s} Tn Tn".format(common.Conj),
+             'grcv_rpn': ["Tn -> Ti | + Tn Tx | + Tv Tn | * Tn | . Tn Tx | . Tv Tn | {0:s} Tn Tn".format(common.Conj),
                            "Tv -> {0:s} | + Tv Tv | * Tv | . Tv Tv | {1:s} Tv Tx | {1:s} Tx Tv".format(common.Epsilon, common.Conj),
                           "Tx -> {0:s} | Ti | +  Tx  Tx  | {1:s} Tx Tx | . Tx Tx  | * Tx".format(common.Epsilon, common.Conj)],
-             'gpt_rpn':  [" Tz ->  + Tz  Tf | Tf",
+             'gpt_rpn':  ["Tz ->  + Tz  Tf | Tf",
                       "Tf -> {0:s} Tf Te | Te".format(common.Conj),
                       "Te -> {0:s} Ts | Ts ".format(common.Not),
                        "Ts -> . Ts Tu | . {0:s} Tu".format(common.SigmaS),
                           "Tu ->  . Ti {0:s}".format(common.SigmaS)],
-             '2D_g_rpn': [ "Tx -> / R R | +  Tx  Tx  | . Tx Tx  | * Tx",
-                            "R -> {0:s} | Ti | +  R  R  | . R R  | * R".format(common.Epsilon)],
-               '2D_gR_rpn': [ "Tx -> / R R ",
-                            "R -> {0:s} | Ti | +  R  R  | . R R  | * R".format(common.Epsilon)],
-                           
-            }
+             '2D_g_rpn': ["Tx -> / r r | +  Tx  Tx  | . Tx Tx  | * Tx",
+                            "r -> {0:s} | Ti | +  r  r  | . r r  | * r".format(common.Epsilon)],
+             '2D_gR_rpn': ["Tx -> / r r ",
+                            "r -> {0:s} | Ti | +  r  r  | . r r  | * r".format(common.Epsilon)],
+             }
