@@ -140,10 +140,10 @@ def unionOfIDs(first, second):
 
 class CodeProperty(object):
     """
-    .. seealso:: K. Dudzinski and S. Konstantinidis: Formal descriptions of code properties: decidability, complexity,
+    **See:** K. Dudzinski and s. Konstantinidis: Formal descriptions of code properties: decidability, complexity,
        implementation. International Journal of Foundations of Computer Science 23:1 (2012), 67--85.
 
-    :var Sigma: the alphabet"""
+    :var sigma: the alphabet"""
     def __init__(self, name, alph):
         if name is None:
             raise CodingTheoryError('new property must have a name')
@@ -175,7 +175,7 @@ class CodeProperty(object):
     def maximalP(self, aut, U=None):
         """Tests if the language is maximal w.r.t. the property
 
-        :param DFA|NFA U: Universe of permitted words (Sigma^* as default)
+        :param DFA|NFA U: Universe of permitted words (sigma^* as default)
         :param DFA|NFA aut: the automaton
         :rtype: bool"""
         pass
@@ -185,7 +185,7 @@ class CodeProperty(object):
         """Witness of non maximality
 
         :param DFA|NFA aut: the automaton
-        :param DFA|NFA U: Universe of permitted words (Sigma^* as default)
+        :param DFA|NFA U: Universe of permitted words (sigma^* as default)
         :return: a witness
         :rtype: str"""
         pass
@@ -213,7 +213,7 @@ class IPTProp(CodeProperty):
     .. inheritance-diagram:: IPTProp
 
     :var SFT Aut: the transducer defining the property
-    :var set Sigma: alphabet"""
+    :var set sigma: alphabet"""
     def __init__(self, aut, name=None):
         """ Constructor
         :param SFT aut: Input preserving transducer"""
@@ -278,7 +278,7 @@ class IPTProp(CodeProperty):
         """Tests if the language is maximal w.r.t. the property
 
         :param DFA|NFA aut: the automaton
-        :param DFA|NFA U: Universe of permitted words (Sigma^* as default)
+        :param DFA|NFA U: Universe of permitted words (sigma^* as default)
         :rtype: bool
         :raises PropertyNotSatisfied: if not satisfied"""
         if not self.satisfiesP(aut):
@@ -296,7 +296,7 @@ class IPTProp(CodeProperty):
         """Tests if the language is maximal w.r.t. the property
 
         :param NFA aut: the automaton
-        :param NFA U: Universe of permitted words (Sigma^* as default)
+        :param NFA U: Universe of permitted words (sigma^* as default)
         :rtype: bool"""
         return self.notMaximalW(aut.toNFA(), U) is None
 
@@ -556,7 +556,7 @@ class FixedProp(CodeProperty):
     def maximalP(self, aut, U=None):
         """Tests if the language is maximal w.r.t. the property
 
-        :param DFA|NFA U: Universe of permitted words (Sigma^* as default)
+        :param DFA|NFA U: Universe of permitted words (sigma^* as default)
         :param DFA|NFA aut: the automaton
         :rtype: bool"""
         pass
@@ -566,7 +566,7 @@ class FixedProp(CodeProperty):
         """Witness of non maximality
 
         :param DFA|NFA aut: the automaton
-        :param DFA|NFA U: Universe of permitted words (Sigma^* as default)
+        :param DFA|NFA U: Universe of permitted words (sigma^* as default)
         :return: a witness
         :rtype: str"""
         pass
@@ -626,7 +626,7 @@ class UDCodeProp(FixedProp):
     def maximalP(self, aut, U=None):
         """Tests if the language is maximal w.r.t. the property
         :param DFA|NFA aut: the automaton
-        :param DFA|NFA U: Universe of permitted words (Sigma^* as default)
+        :param DFA|NFA U: Universe of permitted words (sigma^* as default)
         :rtype: bool"""
         t = infixTransducer(aut.Sigma, True)
         a = aut.dup().star()
@@ -722,7 +722,7 @@ class ErrCorrectProp(ErrDetectProp):
     def satisfiesP(self, aut):
         """Satisfaction of the property by the automaton language
 
-        .. seealso:: S. Konstantinidis: Transducers and the Properties of Error-Detection, Error-Correction and
+        .. seealso:: s. Konstantinidis: Transducers and the Properties of Error-Detection, Error-Correction and
             Finite-Delay Decodability. Journal Of Universal Computer Science 8 (2002), 278-291.
 
         :param DFA|NFA aut: the automaton
@@ -733,7 +733,7 @@ class ErrCorrectProp(ErrDetectProp):
         """Tests if the language is maximal w.r.t. the property
 
         :param DFA|NFA aut: the automaton
-        :param DFA|NFA U: Universe of permitted words (Sigma^* as default)
+        :param DFA|NFA U: Universe of permitted words (sigma^* as default)
         :rtype: bool"""
         return ErrDetectProp(self.Aut.inverse().composition(self.Aut)).notMaximalW(aut, U)
 
@@ -750,7 +750,7 @@ buildUDCodeProp = buildUDCodeProperty
 
 
 def buildTrajPropS(regex, sigma):
-    """Builds a TrajProp from a string regexp
+    """Builds a TrajProp from a string RegExp
 
     :param str regex: the regular expression
     :param set sigma: alphabet
@@ -918,15 +918,16 @@ def createInputAlteringSIDTrans(n, sigmaSet):
 def editDistanceW(auto):
     """Compute the edit distance of a given regular language accepted by the NFA via Input-altering transducer.
 
+    Args:
+        auto(NFA): language recogniser
+    Returns:
+        tuple: The edit distance of the given regular language plus a witness pair
+
     .. attention::
        language should have at least two words
 
     .. seealso:: Lila Kari, Stavros Konstantinidis, Steffen Kopecki, Meng Yang. An efficient algorithm for computing
-        the edit distance of a regular language via input-altering transducers. arXiv:1406.1041 [cs.FL]
-
-    :param NFA auto: language recogniser
-    :return: The edit distance of the given regular language plus a witness pair
-    :rtype: tuple"""
+        the edit distance of a regular language via input-altering transducers. arXiv:1406.1041 [cs.FL]"""
 
     def _normalize(tr):
         tr.States = [(s1, s2, s3, s4) for (((s1, s2), s3), s4) in tr.States]
@@ -1025,14 +1026,15 @@ def editDistanceW(auto):
 
 def exponentialDensityP(aut):
     """ Checks if language density is exponential
+            Using breadth first search (BFS)
 
-    Using breadth first search (BFS)
+    Args:
+        aut(NFA): the representation of the language
+    Returns:
+        bool:
 
     .. attention::
-        aut should not have Epsilon transitions
-
-    :param NFA aut: the representation of the language
-    :rtype: bool"""
+        aut should not have Epsilon transitions"""
     import math
     from collections import deque
 
