@@ -3,9 +3,9 @@
 
 .. *Authors:* Rogério Reis & Nelma Moreira
 
-.. *This is part of FAdo project*   http://fado.dcc.fc.up.pt.
+.. *This is part of FAdo project*   https://fado.dcc.fc.up.pt.
 
-.. *Copyright:* 1999-2014 Rogério Reis & Nelma Moreira {rvr,nam}@dcc.fc.up.pt
+.. *Copyright:* 1999-2022 Rogério Reis & Nelma Moreira {rvr,nam}@dcc.fc.up.pt
 
 .. *Contributions by:*
    - Marco Almeida
@@ -14,7 +14,7 @@
 .. This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as published
    by the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
+   (at your COption) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -32,7 +32,7 @@ from abc import abstractmethod
 import functools
 import tempfile
 import subprocess
-import warnings
+# import warnings
 import re
 from itertools import chain, combinations
 from functools import reduce
@@ -45,10 +45,10 @@ except ImportError:
 
 try:
     from IPython.display import display, SVG  # , get_ipython
-except:
+except ImportError:
     pass
 
-FAdoVersion = "2.0"
+FAdoVersion = "2.0.2"
 __version__ = FAdoVersion
 
 
@@ -121,6 +121,7 @@ class FAdoGeneralError(FAdoError):
 class TypeError(FAdoError):
     pass
 
+
 class VersoError(FAdoGeneralError):
     pass
 
@@ -178,6 +179,10 @@ class FAdoSyntacticError(FAdoError):
     pass
 
 
+class FAdoNotImplemented(FAdoError):
+    pass
+
+
 class DFASyntaticError(DFAerror):
     def __init__(self, line):
         self.line = line
@@ -304,7 +309,7 @@ class SSBadTransition(SSError):
 class regexpInvalid(DFAerror):
     def __init__(self, word):
         self.word = word
-        self.message = 'Error in regexp %s' % word
+        self.message = 'Error in RegExp %s' % word
 
     def __str__(self):
         return "%s" % self.message
@@ -312,7 +317,7 @@ class regexpInvalid(DFAerror):
 
 class regexpInvalidSymbols(DFAerror):
     def __init__(self):
-        self.message = 'Symbols in regexp do not match alphabet'
+        self.message = 'Symbols in RegExp do not match alphabet'
 
     def __str__(self):
         return "%s" % self.message
@@ -388,7 +393,7 @@ class NotSP(DFAerror):
 
 """
 :var EmptySet: default representation for empty set
-:var Epsilon: default representation for epsilon
+:var Epsilon: default representation for CEpsilon
 :var Dot: default representation for "au point" dot
 :var DeadName: default name given to dead states
 """
@@ -426,6 +431,7 @@ ID_OPTION = 6
 ID_SHUFFLE = 7
 ID_EMPTYSET = 8
 
+
 def if_else(a, b, c):
     if a:
         return b
@@ -597,9 +603,9 @@ def dememoize(cls, method_name):
 
 
 try:
-    from itertools import product as cartesianProduct
+    from itertools import product as cartesianproduct
 except ImportError:
-    def cartesianProduct(x, y):
+    def cartesianproduct(x, y):
         return [(a, b) for a in x for b in y]
 
 
@@ -697,14 +703,14 @@ def overlapFreeP(word):
     return True
 
 
-def graphvizTranslate(s, strict=False, maxLblSz=6):
+def graphvizTranslate(s, strict=False, maxlblsz=6):
     """Translate epsilons for graphviz
 
     :param str s: symbol
-    :arg maxLblSz: max size of labels before getting removed
+    :arg maxlblsz: max size of labels before getting removed
     :param bool strict: use limitations of label sizes
     :rtype: str"""
-    return re.sub(Epsilon, "&epsilon;", s)
+    return re.sub(Epsilon, "&CEpsilon;", s)
 
 
 def powerset_generator(i):
@@ -729,100 +735,109 @@ def powerset_generator(i):
 class Drawable(object):
     """Any FAdo object that is drawable"""
 
-    def display(self, fileName=None, size="30,20", strict=False, maxLblSz=6):
+    def display(self, filename=None, size="30,20", strict=False, maxlblsz=6):
         """ Display automata using dot
 
         :arg size: size of representation
         :arg fileName: filename to use for the graphic representation (default a os tmpfile
-        :arg int maxLblSz: max size of labels before getting removed
+        :arg int maxlblsz: max size of labels before getting removed
         :arg bool strict: use limitations of label sizes
 
         .. versionchanged:: 1.2.1"""
-        if fileName is not None:
-            fnameGV = fileName + ".gv"
+        if filename is not None:
+            fname_gv = filename + ".gv"
             if run_from_ipython_notebook():
-                filenameOut = fileName + ".svg"
+                filename_out = filename + ".svg"
             else:
-                filenameOut = fileName + ".pdf"
+                filename_out = filename + ".pdf"
         else:
             f = tempfile.NamedTemporaryFile(suffix=".gv")
             f.close()
-            fnameGV = f.name
-            fname, _ = os.path.splitext(fnameGV)
+            fname_gv = f.name
+            fname, _ = os.path.splitext(fname_gv)
             if run_from_ipython_notebook():
-                filenameOut = fname + ".svg"
+                filename_out = fname + ".svg"
             else:
-                filenameOut = fname + ".pdf"
-        foo = open(fnameGV, "w")
-        foo.write(self.dotFormat(size, strict=strict, maxLblSz=maxLblSz))
+                filename_out = fname + ".pdf"
+        foo = open(fname_gv, "w")
+        foo.write(self.dotFormat(size, strict=strict, maxlblsz=maxlblsz))
         foo.close()
         if run_from_ipython_notebook():
-            callstr = "dot -Tsvg %s -o %s" % (fnameGV, filenameOut)
+            callstr = "dot -Tsvg %s -o %s" % (fname_gv, filename_out)
         else:
-            callstr = "dot -Tpdf %s -o %s" % (fnameGV, filenameOut)
+            callstr = "dot -Tpdf %s -o %s" % (fname_gv, filename_out)
         result = subprocess.call(callstr, shell=True)
         if result:
             print("Need graphviz to visualize objects")
             return
         if run_from_ipython_notebook():
-            display(SVG(filename=filenameOut))
+            display(SVG(filename=filename_out))
         elif os.name == 'nt':
-            os.system("start %s" % filenameOut)
+            os.system("start %s" % filename_out)
         else:
-            os.system("open %s" % filenameOut)
+            os.system("open %s" % filename_out)
 
-    def makePNG(self, fileName=None, size="30,20"):
+    def makePNG(self, filename=None, size="30,20"):
         """ Produce png file to display
 
-        :param str fileName: file name, if None will be a tmpfile
+        :param str filename: file name, if None will be a tmpfile
         :param size: size for graphviz
         :return: name of the file created
 
         .. versionadded:: 1.0.4"""
-        if fileName is not None:
-            fnameGV = fileName + ".gv"
-            fnamePNG = fileName + ".png"
+        if filename is not None:
+            fname_gv = filename + ".gv"
+            fname_png = filename + ".png"
         else:
             f = tempfile.NamedTemporaryFile(suffix=".gv")
             f.close()
-            fnameGV = f.name
-            fname, _ = os.path.splitext(fnameGV)
-            fnamePNG = fname + ".png"
-        foo = open(fnameGV, "w")
+            fname_gv = f.name
+            fname, _ = os.path.splitext(fname_gv)
+            fname_png = fname + ".png"
+        foo = open(fname_gv, "w")
         foo.write(self.dotFormat(size))
         foo.close()
-        callstr = "dot -Tpng %s -o %s" % (fnameGV, fnamePNG)
+        callstr = "dot -Tpng %s -o %s" % (fname_gv, fname_png)
         result = subprocess.call(callstr, shell=True)
         if result:
             print("Need graphviz to visualize objects")
             return
-        return fnamePNG
+        return fname_png
     
-    def dotLabel(self,lbl):
+    def dotLabel(self, lbl0):
         """ Label string
 
         """
-        if type(lbl) == tuple:
-            return "({0:s} , {1:s})".format(self.dotLabel(lbl[0]), self.dotLabel(lbl[1]))
-        elif type(lbl) == set or type(lbl) == list:
-            lbl = list(lbl)
-            if  len(lbl) == 0:
-                return str(lbl)
-            if len(lbl) == 1:
-                return "{0:s}".format(self.dotLabel(lbl[0]))
-            stl = "{0:s}".format(self.dotLabel(lbl[0]))
-            for s in lbl[1:]:
+        if type(lbl0) == tuple:
+            return "({0:s} , {1:s})".format(self.dotLabel(lbl0[0]), self.dotLabel(lbl0[1]))
+        elif type(lbl0) == set or type(lbl0) == list:
+            lbl0 = list(lbl0)
+            if  len(lbl0) == 0:
+                return str(lbl0)
+            if len(lbl0) == 1:
+                return "{0:s}".format(self.dotLabel(lbl0[0]))
+            stl = "{0:s}".format(self.dotLabel(lbl0[0]))
+            for s in lbl0[1:]:
                 stl += ", {0:s}".format(self.dotLabel(s))
             return stl
         else:
-            return str(lbl)
+            return str(lbl0)
         
     @abstractmethod
-    def dotFormat(self, size="20,20", fileName=None, direction="LR", strict=False, maxLblSz=6, sep="\n"):
+    def dotFormat(self, size="20,20", filename=None, direction="LR", strict=False, maxlblsz=6, sep="\n"):
         """Some dot representation
 
-        :param str size: size parameter for dotviz
-        :rtype: str"""
+        Args:
+         size (str): size parameter for dotviz
+         filename (str): filename
+         direction (str):
+         strict (bool):
+         maxlblsz (int):
+         sep (str):
+
+        Returns:
+        str:
+        """
         pass
 
 
@@ -876,10 +891,11 @@ class Word(object):
             return True
         else:
             return self.data == other.data
+
     def __gt__(self, other):
         a, b = len(self.data), len(other.data)
         if a == b:
-            return (self.data > other.data)
+            return self.data > other.data
         elif a < b:
             if self.data > other.data[:a + 1]:
                 return True
@@ -1071,7 +1087,7 @@ def getOneFromSet(s):
 
 
 def sConcat(x, y):
-    """ Concat words
+    """ CConcat words
 
     :param x: first word
     :param y: second word
