@@ -4,14 +4,17 @@
 
 from fa import *
 
-from common import TestsError
+from common import TstError
 
-def evenParity(n=3, sigma=["a", "b"]):
+
+def evenParity(n=3, sigma=None):
     """
      Words of length n with even number of sigma[1]s
     """
+    if sigma is None:
+        sigma = ["a", "b"]
     if len(sigma) != 2:
-        raise TestsError("Size of alphabet must be 2")
+        raise TstError("Size of alphabet must be 2")
     a = DFA()
     a.setSigma(set(sigma))
     a.setInitial(a.addState("initial"))
