@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 """**In/Out.**
 
-FAdo IO.
+FAdo I/O methods. The parsing grammars for most of the objects reside here.
 
 .. *Authors:* Rogério Reis & Nelma Moreira
 
-.. *This is part of FAdo project*   http://fado.dcc.fc.up.pt.
+.. *This is part of FAdo project*   https://fado.dcc.fc.up.pt.
 
-.. *Copyright:* 2014 Rogério Reis & Nelma Moreira {rvr,nam}@dcc.fc.up.pt
+.. *Copyright:* 2014-2022 Rogério Reis & Nelma Moreira {rvr,nam}@dcc.fc.up.pt
 
 .. This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as published
@@ -60,7 +60,7 @@ def readFromFile(FileName):
        * ``@DFA`` or ``@NFA`` begin a new automata (and determines its type) and must be followed by the list of the
          final states separated by blanks
        * fields are separated by a blank and transitions by a CR: ``state`` ``symbol`` ``new state``
-       * in case of a NFA declaration, the "symbol" @epsilon is interpreted as a epsilon-transition
+       * in case of a NFA declaration, the "symbol" @epsilon is interpreted as a CEpsilon-transition
        * the source state of the first transition is the initial state
        * in the case of a NFA, its declaration ``@NFA``  can, after the declaration of the final states,
          have a ``*`` followed by the list of initial states
@@ -74,9 +74,9 @@ def readFromFile(FileName):
        DFA: "@DFA" LsStates Alphabet CR dTrans
        NFA: "@NFA" LsStates Initials Alphabet CR nTrans
        Transducer: "@Transducer" LsStates Initials Alphabet Output CR tTrans
-       Initials: "*" LsStates | /epsilon
-       Alphabet: "$" LsSymbols | /epsilon
-       Output: "$" LsSymbols | /epsilon
+       Initials: "*" LsStates | /CEpsilon
+       Alphabet: "$" LsSymbols | /CEpsilon
+       Output: "$" LsSymbols | /CEpsilon
        nSymbol: symbol | "@epsilon"
        LsStates: stateid | stateid , LsStates
        LsSymbols: symbol | symbol , LsSymbols
@@ -345,7 +345,7 @@ def show(obj):
     """ General, context sensitive, display method
     :param obj: the object to show
 
-    .. versionaded:: 1.2.1 """
+    .. versionadded:: 1.2.1 """
     pass
 
 
@@ -636,80 +636,4 @@ class BuildFadoObject(lark.Transformer):
     dollar = lambda self, _: None
 
 
-FAdoGrammar = lark.Lark(r"""
-    ?object: [(dfa | nfa | transducer | sstransducer | ssfa)+]
-    
-    peg: "@PEG" vars eol pegbody
-    tdpl: "@TDPL" vars eol tdplbody
-    dfa: "@DFA" finals [alphabeti] eol transitions
-    nfa: "@NFA" finals [(star initials)] [alphabeti] eol transitions
-    transducer: "@Transducer" finals [(star initials)] [(alphabeti [(alphabeto)])] eol ttransitions
-    sstransducer: "@SST" finals [(star initials)] alphabeti eol ssttransitions
-    ssfa: "@SSFA" finals [(star initials)] [alphabeti] eol ssatransitions
-    
-    ?alphabet: [var (var)* ]
-    
-    ?var: name 
-    name: /[a-zA-Z0-9]+/ 
-    number: /[0-9]+/
-    
-    finals: [(var)+] 
-    alphabeti: "$" alphabet
-    alphabeto: "$" alphabet
-    
-    transitions: [(strule eol)+]
-    ?strule: statedecl | transition
-    transition: var symbol var
-    
-    ttransitions: [(tstrule eol)+]
-    ?tstrule: statedecl | ttransition
-    ttransition: var symbol symbol var
-    
-    ssttransitions: [(sststrule eol)+]
-    ?sststrule: statedecl | ssttransition
-    ?ssttransition: var pspec var
-    spec: sepsilon | nspec
-    ?nspec: sallspec | sonespec | snotspec
-    sallspec: "@a"
-    sonespec: "@o" names
-    snotspec: "@n" names
-    ?pspec: vpspec | eqpspec | neqpspec
-    vpspec: spec spec
-    eqpspec: nspec "@="
-    sepsilon: "@epsilon"
-    neqpspec: nspec nspec "!"
-    
-    ssatransitions: [(ssatransition eol)+]
-    ?ssatransition: var spec var
-    
-    ?vars: names
-    ?names: [var ( var)* ]
-    
-    pegbody: [(pegrule eol)+]
-    pegrule: var "<-" expr
-    ?expr: "(" expr ")" | var | not | concat | kstar | cond | test 
-    not: "!" expr
-    concat: expr expr
-    kstar: expr star
-    cond: expr SLASH expr
-    !test: AMPERSAND expr
-    
-    tdplbody: [(tdplrule eol)+]
-    tdplrule: var "<-" var var "|" var
-    
-    statedecl: var
-    
-    emptyline: /\n/ 
-    
-    symbol: var | epsilon
-    epsilon: "@epsilon"
-    initials: [var (var)* ] 
-    star: "*"
-    dollar: /\$/
-    AMPERSAND: /&/
-    SLASH: /\//
-    eol: /[\n\r]+/
-    %ignore /[ \t\f\"]+/
-    %ignore /#[^\n]*\n/
-    %ignore /#[^\r\n]*/
-    """, start='object')
+FAdoGrammar = lark.Lark.open("automata_grammar.lark", start="object", rel_to=__file__)
