@@ -248,8 +248,8 @@ class GFT(Transducer):
         :rtype: tuple"""
 
         def _codeOfSet(S):
-            """ Collects into a sorted list the elements of the set S and then
-                returns the string representation of the list. The set S normally
+            """ Collects into a sorted list the elements of the set s and then
+                returns the string representation of the list. The set s normally
                 consists of integers or strings"""
             L = [x for x in S]
             L.sort()
@@ -954,7 +954,7 @@ class SFT(GFT):
         return new
 
     def epsilonP(self):
-        """Test whether this transducer has input epsilon-transitions
+        """Test whether this transducer has input CEpsilon-transitions
 
         :rtype: bool"""
         for s in self.delta:
@@ -963,7 +963,7 @@ class SFT(GFT):
         return False
 
     def addEpsilonLoops(self):
-        """Add a loop transition with epsilon input and output to every state in the transducer."""
+        """Add a loop transition with CEpsilon input and output to every state in the transducer."""
         for i in range(len(self.States)):
             self.addTransition(i, Epsilon, Epsilon, i)
 
@@ -1172,7 +1172,7 @@ class SFT(GFT):
         return new
 
     def epsilonOutP(self):
-        """Tests if epsilon occurs in transition outputs
+        """Tests if CEpsilon occurs in transition outputs
 
         :rtype: bool"""
         for i in self.delta:
