@@ -41,7 +41,7 @@ from . fa import DFA
 
 def emptyDFA(sigma=None):
     """
-    Returns the minimal DFA for emptyset (incomplete)
+    Returns the minimal DFA for EmptySet (incomplete)
 
     :param sigma:
     :return:
@@ -56,7 +56,7 @@ def emptyDFA(sigma=None):
 
 def epsilonDFA(sigma=None):
     """
-    Returns the minimal DFA for {epsilon} (incomplete)
+    Returns the minimal DFA for {CEpsilon} (incomplete)
 
     :param sigma:
     :return:
@@ -95,7 +95,7 @@ witnessDFA = {"toDFA": [("toDFAWCMF", "int"),
 def toDFAWC2MF(m=5,Sigma=["a","b"]):
     """ Worst case automata for toDFA(NFA) with n > 2, k=2
     ..seealso::
-    A. R. Meyer and M. J. Fischer. Economy of description by automata,
+    A. r. Meyer and M. J. Fischer. Economy of description by automata,
     grammars, and formal systems. Twelfth Annual Symposium on
     Switching and Automata Theory, 1971,  188–191. IEEE Society Press.
 
@@ -128,15 +128,15 @@ def toDFAWCReMF(m=5,Sigma=["a","b"]):
     """
     if len(Sigma) != 2:
         raise TstError("Alphabet must be binary")
-    sig=[atom(i) for i in Sigma]
-    r0 = disj(sig[1],concat(concat(sig[0],star(sig[1])),disj(sig[0],sig[1])))
+    sig=[CAtom(i) for i in Sigma]
+    r0 = CDisj(sig[1], CConcat(CConcat(sig[0], CStar(sig[1])), CDisj(sig[0], sig[1])))
     for j in range(1,m-1):
-        r0 = concat(concat(sig[0],star(sig[1])),disj(r0,sig[1]))
-    return star(r0)
+        r0 = CConcat(CConcat(sig[0], CStar(sig[1])), CDisj(r0, sig[1]))
+    return CStar(r0)
 
 def toDFAWC2(m=5):
     """ Worst case automata for toDFA(NFA) with n > 2, k=2
-    ..seealso:: F.R. Moore. On the bounds for state-set size in the proofs
+    ..seealso:: F.r. Moore. On the bounds for state-set size in the proofs
     of equivalence between deterministic, nondeterministic, and
     two-way finite automata. IEEE Transactions on computers, 2:1211–1214, 1971.
 
@@ -224,7 +224,7 @@ def starSC(m=5):
 
 def starWC(m=5):
     """ Worst case automata for star(DFA) with m > 2, k=2
-    ..seealso:: S. Yu, Q. Zhuang, and K. Salomaa. The state complexities
+    ..seealso:: s. Yu, Q. Zhuang, and K. Salomaa. The state complexities
     of some basic operations on regular languages.
     Theor. Comput. Sci., 125(2):315–328, 1994.
 
@@ -332,7 +332,7 @@ def concatWCM(m=4, n=4):
 
 def concatWC(m=6, n=6):
     """ Worst case automata for catenation(DFA,DFA) with m,n > 1
-    ..seealso:: S. Yu, Q. Zhuang, and K. Salomaa. The state complexities
+    ..seealso:: s. Yu, Q. Zhuang, and K. Salomaa. The state complexities
     of some basic operations on regular languages.
     Theor. Comput. Sci., 125(2):315–328, 1994.
     :arg m: number of states
@@ -406,7 +406,7 @@ def concatWCB(m=4, n=4):
 def interWC(m=6, n=5):
     """ Worst case automata for intersection(DFA,DFA) with m,n >1
 
-    ..seealso:: S. Yu, Q. Zhuang, and K. Salomaa. The state complexities
+    ..seealso:: s. Yu, Q. Zhuang, and K. Salomaa. The state complexities
     of some basic operations on regular languages.
     Theor. Comput. Sci., 125(2):315–328, 1994.
     :arg m: number of states
@@ -437,7 +437,7 @@ def interWC(m=6, n=5):
 
 def disjWC(m=6, n=5):
     """ Worst case automata for disjunction(DFA,DFA) with m,n >1
-    ..seealso:: S. Yu, Q. Zhuang, and K. Salomaa. The state complexities
+    ..seealso:: s. Yu, Q. Zhuang, and K. Salomaa. The state complexities
     of some basic operations on regular languages.
     Theor. Comput. Sci., 125(2):315–328, 1994.
     :arg m: number of states
@@ -474,7 +474,7 @@ def disjWC(m=6, n=5):
 def reversalMB(m=8):
     """Worst case automata for reversal(DFA)
 
-    ..seealso:: S. Yu, Q. Zhuang, and K. Salomaa. The state complexities
+    ..seealso:: s. Yu, Q. Zhuang, and K. Salomaa. The state complexities
     of some basic operations on regular languages.
     Theor. Comput. Sci., 125(2):315–328, 1994.
     :arg m: number of states
@@ -560,7 +560,7 @@ def reversalternaryWC(m=5):
 
 def reversalbinaryWC(m=5):
     """Worst case automata for reversal(DFA) binary
-    ..seealso:: G. Jir{\'a}skov{\'a} and J. S\v ebej. Note on Reversal of binary regular languages. Proc. DCFS 2011,
+    ..seealso:: G. Jir{\'a}skov{\'a} and J. s\v ebej. Note on Reversal of binary regular languages. Proc. DCFS 2011,
     LNCS 6808, Springer, pp 212-221.
     @arg m: number of states
     @type m: integer
@@ -597,11 +597,11 @@ def reversalbinaryWC(m=5):
 
 
 def shuffleWC(m=3, n=3):
-    """Worst case automata for shuffle(DFA,DFA) with m.n>1
+    """Worst case automata for CShuffle(DFA,DFA) with m.n>1
 
     ..seealso::
-     C. Campeanu, K. Salomaa, and S. Yu. Tight lower bound for
-    the state complexity of shuffle of regular languages.
+     C. Campeanu, K. Salomaa, and s. Yu. Tight lower bound for
+    the state complexity of CShuffle of regular languages.
     Journal of Automata, Languages and Combinatorics, 7(3):303–310, 2002.
 
     :arg m: number of states
@@ -766,7 +766,7 @@ def disjWStarWC(m=6, n=5):
 def unionWCTk2(m=6, n=6):
     """ @ worst-case family union where
     @m>=2 and n>=2 and k=2
-    ..seealso:: Gao, Y., Salomaa, K., Yu, S.: Transition complexity of
+    ..seealso:: Gao, Y., Salomaa, K., Yu, s.: Transition complexity of
     incomplete dfas. Fundam. Inform.  110(1-4), 143–158 (2011)
     @ the conjecture in this article fails for this family
     :arg m: number of states
@@ -1278,57 +1278,57 @@ def suffFreeSyntWC(m=5):
 
 
 
-#shuffle
+#CShuffle
 
 def shuffle_ReBC(n=3):
-    """ Withess for Shuffle toDFA
+    """ Withess for CShuffle toDFA
     """
 
     if n < 2:
         raise TstError("at least n=2")
-    rs = star(concat(atom('a0'), atom('b0')))
+    rs = CStar(CConcat(CAtom('a0'), CAtom('b0')))
     for i in range(1, n):
-        rs = shuffle(rs,star(concat(atom('a'+str(i)),atom('b'+str(i)))))
+        rs = Shuffle(rs, CStar(CConcat(CAtom('a' + str(i)), CAtom('b' + str(i)))))
     return rs
 
 def shuffle_ReBCF(n=3):
     """
     :param n:
-    :return:regexp
+    :return:RegExp
     """
     if n<2:
         raise TstError("at least n=2")
-    rs = concat(atom('a0'),atom('b0'))
+    rs = CConcat(CAtom('a0'), CAtom('b0'))
     for i in range(1,n):
-        rs = shuffle(rs,concat(atom('a'+str(i)),atom('b'+str(i))))
+        rs = Shuffle(rs, CConcat(CAtom('a' + str(i)), CAtom('b' + str(i))))
     return rs
 
 def shuffle_NFABC(n=3):
     """
 
     :param  int n:
-    :rtype: atom
+    :rtype: CAtom
     """
     if n<2:
         raise TstError("at least n=2")
-    ns = star(concat(atom('a0'), atom('b0'))).toNFA()
+    ns = CStar(CConcat(CAtom('a0'), CAtom('b0'))).toNFA()
     for i in range(1, n):
-        ni = star(concat(atom('a'+str(i)), atom('b'+str(i)))).toNFA()
-        ns = ns.shuffle(ni)
+        ni = CStar(CConcat(CAtom('a' + str(i)), CAtom('b' + str(i)))).toNFA()
+        ns = ns.CShuffle(ni)
     return ns
 
 
 def shuffle_ReWC(n=4):
     """
-    Regular expressions for worst case partial derivative automaton from shuffle operator
+    Regular expressions for worst case partial derivative automaton from CShuffle operator
     :param int n:
-    :rtype: atom
+    :rtype: CAtom
     """
     if n<2:
         raise TstError("at least n=2")
-    rs = atom('a0')
+    rs = CAtom('a0')
     for i in range(1, n):
-        rs = shuffle(rs, atom('a'+str(i)))
+        rs = Shuffle(rs, CAtom('a' + str(i)))
     return rs
 
 
@@ -1337,22 +1337,22 @@ def intersectionReWC(n, sym = 'a'):
     Regular expressions for "bad" case partial derivative automaton from intersection  operator
     :param n: number of letters
     :param sym: alphabetic symbol
-    :return: regexp
+    :return: RegExp
     """
     if n == 0:
-        return epsilon()
+        return CEpsilon()
     if n == 1:
-        return star(atom(sym))
+        return CStar(CAtom(sym))
     else:
         s1 = set()
         s2 = set()
         for i in range(1,n+1):
             ri = str2xre(sym * i)
-            s1.add(star(ri))
+            s1.add(CStar(ri))
             s2.add(ri)
-        r1 = sdisj(frozenset(s1))
-        r2 = sstar(sdisj(frozenset(s2)))
-        return sconj(frozenset([r1,r2]))
+        r1 = SDisj(frozenset(s1))
+        r2 = SStar(SDisj(frozenset(s2)))
+        return SConj(frozenset([r1, r2]))
 
 def intersectionRetoReLB(m=3,n=3, Sigma=["a","b"]):
     """
@@ -1363,13 +1363,13 @@ def intersectionRetoReLB(m=3,n=3, Sigma=["a","b"]):
     :param n: alphabetic size
     :return: regular expression for the intersection
     """
-    a=atom(Sigma[0])
-    b=atom(Sigma[1])
-    bs=star(b)
+    a=CAtom(Sigma[0])
+    b=CAtom(Sigma[1])
+    bs=CStar(b)
     r1= a
     for i in range(m):
-        r1 = concat(r1,concat(bs,a))
-    return star(disj(b,r1))
+        r1 = CConcat(r1, CConcat(bs, a))
+    return CStar(CDisj(b, r1))
 
 
 
